Coverage for /home/tribaal/workspace/django-shop/shop/urls/order: 100.00%

# Coverage for /home/tribaal/workspace/django-shop/shop/urls/order : 100.00%

## 3 statements 3 run 0 missing 0 excluded 0 partial

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 | from django.conf.urls.defaults import patterns, url from shop.views.order import OrderListView, OrderDetailView urlpatterns = patterns('', url(r'^$', OrderListView.as_view(), name='order_list'), url(r'^(?P<pk>\d+)/$', OrderDetailView.as_view(), name='order_detail'), )